
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef pilo_TCLSERV_CLIENT_ERROR_H
#define pilo_TCLSERV_CLIENT_ERROR_H

#include <server/piloError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum pilo_error {
	E_pilo_OK					  			= 0,

	/* module errors */
	E_pilo_NO_MORE_TRAJ                   = S_pilo_NO_MORE_TRAJ,
	E_pilo_PATH_BLOCKED                   = S_pilo_PATH_BLOCKED,
	E_pilo_IMPORTANT_DRIFT                = S_pilo_IMPORTANT_DRIFT,
	E_pilo_INVALID_INITIAL_POSITION       = S_pilo_INVALID_INITIAL_POSITION,
	E_pilo_ERROR_IN_RS_COMPUTATION        = S_pilo_ERROR_IN_RS_COMPUTATION,
	E_pilo_NUL_SPEED_MOTION               = S_pilo_NUL_SPEED_MOTION,
	E_pilo_ERROR_IN_DYNAMIC               = S_pilo_ERROR_IN_DYNAMIC,
	E_pilo_bad_parameters                 = S_pilo_bad_parameters,
	E_pilo_POSTER_NOT_FOUND               = S_pilo_POSTER_NOT_FOUND,


	/* std errors */
	E_pilo_ACTIVITY_INTERRUPTED           = S_pilo_stdGenoM_ACTIVITY_INTERRUPTED,
	E_pilo_TOO_MANY_ACTIVITIES            = S_pilo_stdGenoM_TOO_MANY_ACTIVITIES,
	E_pilo_ACTIVITY_FAILED                = S_pilo_stdGenoM_ACTIVITY_FAILED,
	E_pilo_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_pilo_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_pilo_UNKNOWN_ACTIVITY               = S_pilo_stdGenoM_UNKNOWN_ACTIVITY,
	E_pilo_FORBIDDEN_ACTIVITY_TRANSITION  = S_pilo_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_pilo_SYSTEM_ERROR                   = S_pilo_stdGenoM_SYSTEM_ERROR,
	E_pilo_ACTIVITY_ALREADY_ENDED         = S_pilo_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_pilo_WAIT_INIT_RQST                 = S_pilo_stdGenoM_WAIT_INIT_RQST,
	E_pilo_CONTROL_CODEL_ERROR            = S_pilo_stdGenoM_CONTROL_CODEL_ERROR,
	E_pilo_EXEC_TASK_SUSPENDED            = S_pilo_stdGenoM_EXEC_TASK_SUSPENDED,
	E_pilo_BAD_BLOCK_TYPE                 = S_pilo_stdGenoM_BAD_BLOCK_TYPE,
	E_pilo_BAD_POSTER_TYPE                = S_pilo_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum pilo_error pilo_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int pilo_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the pilo context.
 *
 * Returns NULL in case of failure
 */
const char* pilo_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
